@@ -6,7 +6,7 @@ from django.core.cache import cache
 from dbsettings.models import Setting
 
 __all__ = ['get_all_settings', 'get_setting', 'get_setting_storage',
-    'register_setting', 'set_setting_value']
+    'register_setting', 'unregister_setting', 'set_setting_value']
 
 class SettingDict(SortedDict):
     "Sorted dict that has a bit more list-type functionality"
@@ -50,10 +50,12 @@ def get_setting_storage(module_name, class_name, attribute_name):
     return storage
 
 def register_setting(setting):
-    if setting not in _settings:
+    if setting.key not in _settings:
         _settings.insert(bisect(list(_settings), setting), setting.key, setting)
-    else:
-        _settings[setting.key] = setting
+
+def unregister_setting(setting):
+    if setting.key in _settings and _settings[setting.key] is setting:
+        del _settings[setting.key]
 
 def set_setting_value(module_name, class_name, attribute_name, value):
     setting = get_setting(module_name, class_name, attribute_name)
